ALTER TABLE `lh_chat_archive_range` ADD `year_month` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_chat_archive_range` ADD `older_than` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_chat_archive_range` ADD `last_id` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_chat_archive_range` ADD `first_id` int(11) NOT NULL, COMMENT='';