ALTER TABLE `lh_abstract_widget_theme` ADD `widget_show_leave_form` tinyint(1) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_widget_theme` ADD `enable_widget_embed_override` tinyint(1) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_widget_theme` ADD `widget_popheight` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_widget_theme` ADD `widget_popwidth` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_widget_theme` ADD `widget_survey` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_widget_theme` ADD `widget_position` varchar(50) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_widget_theme` ADD `widget_pright` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_widget_theme` ADD `widget_pbottom` int(11) NOT NULL, COMMENT='';