INSERT INTO `lh_chat_config` (`identifier`,`value`,`type`,`explain`,`hidden`) VALUES ('autoclose_timeout_pending','0','0','Automatic pending chats closing. 0 - disabled, n > 0 time in minutes before chat is automatically closed','0');
INSERT INTO `lh_chat_config` (`identifier`,`value`,`type`,`explain`,`hidden`) VALUES ('autoclose_timeout_active','0','0','Automatic active chats closing. 0 - disabled, n > 0 time in minutes before chat is automatically closed','0');
INSERT INTO `lh_chat_config` (`identifier`,`value`,`type`,`explain`,`hidden`) VALUES ('autoclose_timeout_bot','0','0','Automatic bot chats closing. 0 - disabled, n > 0 time in minutes before chat is automatically closed','0');
INSERT INTO `lh_chat_config` (`identifier`,`value`,`type`,`explain`,`hidden`) VALUES ('open_closed_chat_timeout','1800','0','How many seconds customer has to open already closed chat.','0');