ALTER TABLE `lh_generic_bot_tr_group` ADD `nick` varchar(100) NOT NULL, COMMENT='';
ALTER TABLE `lh_generic_bot_tr_group` ADD `configuration` longtext NOT NULL, COMMENT='';
ALTER TABLE `lh_generic_bot_tr_group` ADD `filepath` varchar(250) NOT NULL, COMMENT='';
ALTER TABLE `lh_generic_bot_tr_group` ADD `filename` varchar(250) NOT NULL, COMMENT='';