ALTER TABLE `lh_abstract_widget_theme` ADD `show_need_help` int(11) NOT NULL DEFAULT '1', COMMENT='';
ALTER TABLE `lh_abstract_widget_theme` ADD `show_need_help_timeout` int(11) NOT NULL DEFAULT '24', COMMENT='';