ALTER TABLE `lh_abstract_survey` CHANGE `max_stars` `max_stars_1` int(11) NOT NULL;
ALTER TABLE `lh_abstract_survey` ADD `max_stars_1_title` varchar(250) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_1_pos` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_1_enabled` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_2_title` varchar(250) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_2_pos` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_2` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_2_enabled` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_3_title` varchar(250) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_3_pos` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_3` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_3_enabled` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_4_title` varchar(250) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_4_pos` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_4` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_4_enabled` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_5_title` varchar(250) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_5_pos` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_5` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `max_stars_5_enabled` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_1` varchar(250) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_1_items` text NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_1_pos` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_1_enabled` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_2` varchar(250) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_2_items` text NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_2_pos` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_2_enabled` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_3` varchar(250) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_3_items` text NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_3_pos` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_3_enabled` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_4` varchar(250) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_4_enabled` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_4_items` text NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_4_pos` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_5` varchar(250) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_5_items` text NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_5_pos` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_options_5_enabled` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_plain_1` text NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_plain_1_pos` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_plain_1_enabled` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_plain_2` text NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_plain_2_pos` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_plain_2_enabled` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_plain_3` text NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_plain_3_pos` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_plain_3_enabled` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_plain_4` text NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_plain_4_pos` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_plain_4_enabled` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_plain_5` text NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_plain_5_pos` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey` ADD `question_plain_5_enabled` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey_item` CHANGE `stars` `max_stars_1` int(11) NOT NULL;
ALTER TABLE `lh_abstract_survey_item` ADD `max_stars_2` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey_item` ADD `max_stars_3` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey_item` ADD `max_stars_4` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey_item` ADD `max_stars_5` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey_item` ADD `question_options_1` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey_item` ADD `question_options_2` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey_item` ADD `question_options_3` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey_item` ADD `question_options_4` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey_item` ADD `question_options_5` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey_item` ADD `question_plain_1` text NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey_item` ADD `question_plain_2` text NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey_item` ADD `question_plain_3` text NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey_item` ADD `question_plain_4` text NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey_item` ADD `question_plain_5` text NOT NULL, COMMENT='';
ALTER TABLE `lh_abstract_survey_item` ADD INDEX `max_stars_1` (`max_stars_1`);
ALTER TABLE `lh_abstract_survey_item` ADD INDEX `max_stars_2` (`max_stars_2`);
ALTER TABLE `lh_abstract_survey_item` ADD INDEX `max_stars_3` (`max_stars_3`);
ALTER TABLE `lh_abstract_survey_item` ADD INDEX `max_stars_4` (`max_stars_4`);
ALTER TABLE `lh_abstract_survey_item` ADD INDEX `max_stars_5` (`max_stars_5`);
ALTER TABLE `lh_abstract_survey_item` ADD INDEX `question_options_1` (`question_options_1`);
ALTER TABLE `lh_abstract_survey_item` ADD INDEX `question_options_2` (`question_options_2`);
ALTER TABLE `lh_abstract_survey_item` ADD INDEX `question_options_3` (`question_options_3`);
ALTER TABLE `lh_abstract_survey_item` ADD INDEX `question_options_4` (`question_options_4`);
ALTER TABLE `lh_abstract_survey_item` ADD INDEX `question_options_5` (`question_options_5`);
ALTER TABLE `lh_canned_msg` CHANGE `msg` `msg` longtext NOT NULL;
ALTER TABLE `lh_msg` CHANGE `msg` `msg` longtext NOT NULL;