ALTER TABLE `lh_chat_blocked_user` ADD `chat_id` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_chat_blocked_user` ADD `dep_id` int(11) NOT NULL, COMMENT='';
ALTER TABLE `lh_chat_blocked_user` ADD `nick` varchar(50) NOT NULL, COMMENT=''; 